@@ -55,6 +55,14 @@ class BaseFunctions(SalureConnect):
         }
         return headers
 
+    def renew_authorization_headers(self):
+        """
+        Renew the access token
+        :return: returns the retrieved access_token
+        """
+        credentials = self.get_system_credential(system='sap', label=self.label)
+        self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], self.certificate_file, self.key_file, credentials['client_secret'])
+
     def get_data(self, uri: str, filter: str = None, xml_root: list = []):
         """
         :param uri: The endpoint to call
@@ -66,8 +74,8 @@ class BaseFunctions(SalureConnect):
         url = f"{self.base_url}/{uri}?$filter={filter}" if filter is not None else f"{self.base_url}/{uri}"
         response = requests.request("GET", f"{url}", headers=self.headers, data={})
         if response.status_code == 401:
-            credentials = self.get_system_credential(system='sap', label=self.label)
-            self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], self.certificate_file, self.key_file, credentials['client_secret'])
+            self.renew_authorization_headers()
+            response = requests.request("GET", f"{url}", headers=self.headers, data={})
         if self.debug:
             print(response.text)
         if response.status_code >= 300:
@@ -108,8 +116,8 @@ class BaseFunctions(SalureConnect):
         if self.debug:
             return response
         if response.status_code == 401:
-            credentials = self.get_system_credential(system='sap', label=self.label)
-            self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], self.certificate_file, self.key_file, credentials['client_secret'])
+            self.renew_authorization_headers()
+            response = requests.request("POST", url, headers=self.headers, data=json.dumps(data))
         # Don't use raise_for_status() here because the errors from SAP will come in XML format which can be parsed here
         if response.status_code == 201:
             if len(response.text) == 0 or return_key is None:
@@ -151,8 +159,8 @@ class BaseFunctions(SalureConnect):
         url = f"{self.base_url}/{uri}/{filter}" if filter is not None else f"{self.base_url}/{uri}"
         response = requests.request("DELETE", f"{url}", headers=self.headers)
         if response.status_code == 401:
-            credentials = self.get_system_credential(system='sap', label=self.label)
-            self.headers = self.get_authorization_headers(credentials['client_id'], credentials['authorisation_url'], self.certificate_file, self.key_file, credentials['client_secret'])
+            self.renew_authorization_headers()
+            response = requests.request("DELETE", f"{url}", headers=self.headers)
         return response
 
     def exclude_expired_objects(self, df, col='end_date', expiration_date=datetime.datetime.today()):
