@@ -116,15 +116,17 @@ class DelimitEndpoints:
         response.raise_for_status()
         return response
 
-    def delimit_power_of_attorney(self, employee_id, start_date, end_date):
+    def delimit_power_of_attorney(self, employee_id, start_date, end_date, power_of_attorney_code, company_code):
         """
         Delimit power of attorney in SAP
         :param employee_id: the AFAS ID of the employee in case
         :param start_date: the start date of the record you want to delimit
         :param end_date: the end date at which the record will be delimit
+        :param power_of_attorney_code: the code of the power of attorney you want to delimit
+        :param company_code: the company code of the power of attorney you want to delimit
         :return: status
         """
-        data_filter = f"Afasemployeenumber='{employee_id}',Startdate='{start_date}',Enddate='{end_date}'"
+        data_filter = f"Afasemployeenumber='{employee_id}',Startdate='{start_date}',Enddate='{end_date}',PowerOfAttorney='{power_of_attorney_code}',CompanyCode='{company_code}'"
         response = self.base_class.delete_data(uri="PowersAttorneyDel", filter=data_filter)
         response.raise_for_status()
         return response
